/*************************************************************************

	File Name	: OutlinePanel.java

	Author		: Kim, Dongmin

	Function	: Make a out line of the object with title.

	Input		:

		CFD smain	  : CFD main class
		String title	  : title to be displayed
		int fontSize	  : the font size of the title
		int borderGap 	  : the gap between the border and the line
		int titleGap	  : the gap between the title and the line
		int titleGapFront : the gap between the border and the title

**************************************************************************/

import java.awt.*;
import java.util.*;
import java.lang.*;
import java.awt.event.*;
import java.applet.Applet;

public class OutlinePanel extends Panel {

	CFD smain;
	String title = null;
	Font titleFont;
	FontMetrics titleFontMetrics;

	int borderGap;
	int titleGap;
	int titleGapFront;

	int title_font_size;
	int title_size;

       /*****************************************************************
	*
	*	method	 : OutlinePanel()
	*
	*	Function : constructor of this class
	*
	*****************************************************************/
	OutlinePanel(
		CFD smain, String title,
		int fontSize, int borderGap, 
		int titleGap, int titleGapFront) {

		this.smain = smain;
		this.borderGap = borderGap;
		this.titleGap = titleGap;
		this.titleGapFront = titleGapFront;
		this.title = title;

		setLayout(new BorderLayout());
		titleFont = new Font("Dialog", Font.BOLD, fontSize);
		titleFontMetrics = getFontMetrics(titleFont);
	}

       /*****************************************************************
	*
	*	method	 : paint()
	*	Input    : Graphics g
	*	Output   : none
	*
	*****************************************************************/
	public void paint(Graphics g) {

		int titleX;
		int titleY;

		Dimension r = getSize();
		title_font_size = titleFont.getSize();
		title_size = titleFontMetrics.stringWidth(title);
		g.setFont(titleFont);

		titleX = titleGapFront + titleGap;
		titleY = borderGap + title_font_size / 2;

		g.drawString(title, titleX, titleY);

		g.drawLine(borderGap, borderGap, titleGapFront, borderGap);
		g.drawLine(title_size + titleGapFront + titleGap * 2, 
				borderGap, r.width - borderGap, borderGap);
		g.drawLine(borderGap, borderGap, 
				borderGap, r.height - borderGap);
		g.drawLine(borderGap, r.height - borderGap, 
				r.width - borderGap, r.height - borderGap);
		g.drawLine(r.width - borderGap, borderGap, 
				r.width - borderGap, r.height - borderGap);
	}

       /*****************************************************************
	*
	*	method	 : insets()
	*	Input    : none
	*	Output   : Insets
	*
	*****************************************************************/
	public Insets insets() {
		return new Insets(borderGap * 2 + title_font_size / 2, borderGap * 2, 
					borderGap * 2, borderGap * 2);
	}

}
